@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "plugineditorcheckbeforesendparams.h"
@@ -25,10 +12,6 @@ class MessageComposer::PluginEditorCheckBeforeSendParamsPrivate
 {
 public:
     PluginEditorCheckBeforeSendParamsPrivate()
-        : identity(-1)
-        , transportId(-1)
-        , isHtml(false)
-        , hasAttachment(false)
     {
     }
 
@@ -38,10 +21,10 @@ public:
     QString plainText;
     QString subject;
     QString defaultDomain;
-    uint identity;
-    int transportId;
-    bool isHtml;
-    bool hasAttachment;
+    int transportId = -1;
+    bool isHtml = false;
+    uint identity = 0;
+    bool hasAttachment = false;
 };
 
 PluginEditorCheckBeforeSendParams::PluginEditorCheckBeforeSendParams()
